@@ -296,8 +296,7 @@ def parse_command_line(argv):
         dest="timeout_seconds",
         type=timeout,
         default=30,
-        help="set GRUB timeout in whole seconds or -1 to disable"
-        " (default: %(default)s seconds)",
+        help="set GRUB timeout in whole seconds or -1 to disable (default: %(default)s seconds)",
     )
     parser.add_argument(
         "--add",
@@ -434,7 +433,9 @@ def _grub2_ovmf_tuple():
     else:
         candidates = [
             "/usr/share/edk2-ovmf/OVMF_CODE.fd",  # Gentoo and its derivatives
-            "/usr/share/edk2-ovmf/x64/OVMF_CODE.fd",  # Arch Linux and its derivatives
+            "/usr/share/edk2-ovmf/x64/OVMF_CODE.fd",  # Older Arch Linux and its derivatives
+            "/usr/share/edk2/x64/OVMF.4m.fd",  # Arch Linux and its derivatives
+            "/usr/share/edk2/x64/OVMF_CODE.4m.fd",  # Arch Linux and its derivatives
             "/usr/share/OVMF/OVMF_CODE.fd",  # Older Debian and its derivatives
             "/usr/share/OVMF/OVMF_CODE_4M.fd",  # Debian and its derivatives
             "/usr/share/edk2/ovmf/OVMF_CODE.fd",  # Fedora (and its derivatives?)
